@@ -14,8 +14,8 @@ class JacBookTests(TestCaseHelper, TestCase):
 
     def setUp(self):
         super().setUp()
-        self.sent = Sentinel(m_id="anon", h=MetaService().build_hook())
-        self.gph = Graph(m_id="anon", h=self.sent._h)
+        self.sent = Sentinel(m_id=0, h=MetaService().build_hook())
+        self.gph = Graph(m_id=0, h=self.sent._h)
         self.old_stdout = sys.stdout
         self.new_stdout = io.StringIO()
         sys.stdout = self.new_stdout
