@@ -1,5 +1,4 @@
 import os
-import sys
 
 DEFAULT_MSG = "Skipping scheduled walker!"
 DEFAULT_URL = (
@@ -16,8 +15,3 @@ TASK_CONFIG = {
     "task_track_started": True,
     "worker_redirect_stdouts": False,
 }
-
-
-if "python3 -m unittest" in sys.argv:
-    TASK_CONFIG["task_always_eager"] = True
-    TASK_CONFIG["task_store_eager_result"] = True
