@@ -3,7 +3,6 @@ import os
 import pstats
 import cProfile
 import pdb
-import uuid
 import importlib
 import pkgutil
 import logging
@@ -44,13 +43,16 @@ def connect_logger_handler(target_logger, handler, level=logging.WARN):
 
 logger = logging.getLogger("core")
 logger.propagate = False
+logs = io.StringIO()
 if len(logger.handlers) < 1:
     connect_logger_handler(logger, logging.StreamHandler(), logging.INFO)
+    connect_logger_handler(logger, logging.StreamHandler(stream=logs), logging.INFO)
 
 app_logger = logging.getLogger("app")
 app_logger.propagate = False
 if len(app_logger.handlers) < 1:
     connect_logger_handler(app_logger, logging.StreamHandler(), logging.INFO)
+    connect_logger_handler(app_logger, logging.StreamHandler(stream=logs), logging.INFO)
 
 
 def log_var_out(val):
@@ -200,9 +202,10 @@ def perf_test_start():
     return perf_prof
 
 
-def perf_test_stop(perf_prof):
+def perf_test_stop(perf_prof, save_to_file=False):
     perf_prof.disable()
-    perf_prof.dump_stats(f"{id(perf_prof)}.prof")
+    if save_to_file:
+        perf_prof.dump_stats(f"{id(perf_prof)}.prof")
     s = io.StringIO()
     sortby = pstats.SortKey.CUMULATIVE
     ps = pstats.Stats(perf_prof, stream=s).sort_stats(sortby)
